/*++
/* NAME
/*	tls_log_mask 3
/* SUMMARY
/*	TLS logging
/* SYNOPSIS
/*	#include <tls.h>
/*
/*	int	tls_log_mask(param_name, param_value)
/*	const char *param_name;
/*	const char *param_value;
/* DESCRIPTION
/*	tls_log_mask() takes the string value of the named configuration
/*	parameter (0..4, none, untrusted, etc.) and converts it to
/*	a logging mask. When the input specifies an invalid logging
/*	level, tls_log_mask() logs a warning and returns TLS_LOG_INVALID.
/* LICENSE
/* .ad
/* .fi
/*	This software is free. You can do with it whatever you want.
/*	The original author kindly requests that you acknowledge
/*	the use of his software.
/* AUTHOR(S)
/*	Originally written by:
/*	Lutz Jaenicke
/*	BTU Cottbus
/*	Allgemeine Elektrotechnik
/*	Universitaetsplatz 3-4
/*	D-03044 Cottbus, Germany
/*
/*	Updated by:
/*	Wietse Venema
/*	IBM T.J. Watson Research
/*	P.O. Box 704
/*	Yorktown Heights, NY 10598, USA
/*
/*	Victor Duchovni
/*	Morgan Stanley
/*--*/

/* System library. */

#include <sys_defs.h>
#include <ctype.h>
#include <string.h>

/* Utility library. */

#include <vstream.h>
#include <msg.h>
#include <mymalloc.h>
#include <vstring.h>
#include <stringops.h>

/* TLS library. */

#include <tls.h>

/* Application-specific. */

#define TLS_LOG_U TLS_LOG_UNTRUSTED
#define TLS_LOG_US TLS_LOG_U | TLS_LOG_SUMMARY
#define TLS_LOG_USV TLS_LOG_US | TLS_LOG_VERBOSE
#define TLS_LOG_USVC TLS_LOG_USV | TLS_LOG_CACHE

 /*
  * Log features for client and server logging.
  */
NAME_MASK tls_log_table[] = {
    "0", TLS_LOG_U,
    "1", TLS_LOG_US,
    "2", TLS_LOG_USVC | TLS_LOG_DEBUG,
    "3", TLS_LOG_USVC | TLS_LOG_DEBUG | TLS_LOG_TLSPKTS,
    "4", TLS_LOG_USVC | TLS_LOG_DEBUG | TLS_LOG_TLSPKTS | TLS_LOG_ALLPKTS,
    "none", 0,
    "untrusted", TLS_LOG_UNTRUSTED,
    "summary", TLS_LOG_SUMMARY,
    "verbose", TLS_LOG_USV,
    "cache", TLS_LOG_CACHE,
    "certmatch", TLS_LOG_USV | TLS_LOG_CERTMATCH,
    "debug", TLS_LOG_USVC | TLS_LOG_DEBUG,
    "handshake-packet-dump", TLS_LOG_DEBUG | TLS_LOG_TLSPKTS,
    "session-packet-dump", TLS_LOG_DEBUG | TLS_LOG_TLSPKTS | TLS_LOG_ALLPKTS,
    0, TLS_LOG_INVALID,
};
